#!/bin/bash
##################################################
#Installation of java-pack
#Prerequisites: Copy the zip file to the build dir
#build directory eg:  
##################################################

tempdir="tempidi"
backupdir="backup"
backupjvmdir="_jvm_52GA"
zipball="ITDI_JP52_aix.tar.gz"
tarball="ITDI_JP52_aix.tar"


##################################################
#Check if the zip file exists
##################################################

if [ ! -f $zipball ]; then
	echo Error: $zipball not in this directory.
	echo Please copy $zipball to this directory.
	exit 1
fi

##################################################
#Clean up all the previous directories		 #	
#								 #
##################################################
if [ -d $tempdir ]; then
	echo Cleaning $tempdir ...
	rm -rf $tempdir
fi

echo Creating $tempdir
mkdir $tempdir
mkdir $tempdir/_jvm

if [ -d $backupdir ]; then
	echo $backupdir already exists...
else
	echo Creating $backupdir ...
	mkdir $backupdir
			
fi
if [ -d $backupdir/$backupjvmdir ]; then
	echo $backupdir/$backupjvmdir is present
	echo Please check if the jvm has already been updated
	echo If you still want to update the jvm delete 
	echo $backupdir/$backupjvmdir directory and retry
	exit 1
fi

##################################################
#Untar all the files to temp directory
##################################################
echo Untar jvm to the temp dir...
cp "$zipball" $tempdir/_jvm
cd $tempdir/_jvm
	gunzip $zipball
	if [ $? -ne 0 ]; then
		echo Please install gunzip. Exiting...
		exit 2 
	fi
	tar -xf $tarball
	rm -rf $tarball
cd ../..

##################################################
#Backup the previous jvm and replace with existing
##################################################
echo backing up the jvm...
if [ -d _jvm ]; then
	echo _jvm is backed up
	cp -rf _jvm/ $backupdir/
        mv $backupdir/_jvm $backupdir/$backupjvmdir
else 
	echo Existing jvm not present. Cannot be backup up...
fi


echo Copying the new jvm...
cp -rf $tempdir/_jvm . 

#Change for AIX/ppc/s390 only
echo Restoring previous java.security
cp $backupdir/$backupjvmdir/jre/lib/security/java.security ./_jvm/jre/lib/security/java.security

########################################################
# Delete unwanted stuff
########################################################
echo removing $tempdir ....
rm -rf $tempdir

#change the permissions of the existing directory
chmod -R a+x _jvm
chmod -R a+x $backupdir/$backupjvmdir

########################################################
# Check if the java pack is installed properly
########################################################
#changed for AIX/s390/ppc
echo Please verify the jvm versions....
echo The older jvm was 
$backupdir/$backupjvmdir/jre/bin/java -fullversion
#changed for AIX/ppc/s390 : added extra jre
echo The newer jvm is 
_jvm/jre/bin/java -fullversion

